@@ -1,4 +1,4 @@
-from django.conf.urls import url, include
+import django
 from eremaea import views
 from rest_framework.routers import DefaultRouter
 
@@ -7,6 +7,11 @@ router.register(r'collections', views.CollectionViewSet)
 router.register(r'snapshots', views.SnapshotViewSet)
 router.register(r'retention_policies', views.RetentionPolicyViewSet, basename='retention_policy')
 
+if django.VERSION[0] > 1:
+	from django.urls import include, re_path
+else:
+	from django.conf.urls import include, url as re_path
+
 urlpatterns = [
-	url(r'^', include(router.urls)),
+	re_path(r'^', include(router.urls)),
 ]
